# ngscheck_client

A command-line client to submit jobs to and retrieve results from a remote
NGSCheck service presented as a REST API.

Install: `pip3 install --user ngscheck_client`

Help: `ngscheck_client -h`
